@@ -102,11 +102,7 @@ void KateViewTest::testReloadMultipleViews()
     for (int i = 0; i < 200; ++i) {
         stream << line;
     }
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-    stream << flush;
-#else
     stream << Qt::flush;
-#endif
     file.close();
 
     KTextEditor::DocumentPrivate doc;
@@ -186,11 +182,7 @@ void KateViewTest::testSelection()
     stream << "A\n"
            << "B\n"
            << "C";
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-    stream << flush;
-#else
     stream << Qt::flush;
-#endif
     file.close();
 
     KTextEditor::DocumentPrivate doc;
@@ -217,7 +209,8 @@ void KateViewTest::testSelection()
 
     QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseMove, afterA + QPoint(50, 0), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier));
 
-    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonRelease, afterA + QPoint(50, 0), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier));
+    QCoreApplication::sendEvent(internalView,
+                                new QMouseEvent(QEvent::MouseButtonRelease, afterA + QPoint(50, 0), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier));
 
     QCOMPARE(view->cursorPosition(), Cursor(0, 1));
     QVERIFY(!view->selection());
