@@ -33,8 +33,8 @@
 #if 0
 #define BUFFER_DEBUG qCDebug(LOG_KTE)
 #else
-#define BUFFER_DEBUG                                                                                                                                                                                                                           \
-    if (0)                                                                                                                                                                                                                                     \
+#define BUFFER_DEBUG                                                                                                                                           \
+    if (0)                                                                                                                                                     \
     qCDebug(LOG_KTE)
 #endif
 
@@ -128,7 +128,7 @@ void TextBuffer::clear()
     m_blocks.clear();
 
     // insert one block with one empty line
-    m_blocks.append(newBlock);
+    m_blocks.push_back(newBlock);
 
     // reset lines and last used block
     m_lines = 1;
@@ -147,7 +147,7 @@ void TextBuffer::clear()
     m_history.clear();
 
     // we got cleared
-    emit cleared();
+    Q_EMIT cleared();
 }
 
 TextLine TextBuffer::line(int line) const
@@ -189,9 +189,9 @@ bool TextBuffer::startEditing()
     m_editingMaximalLineChanged = -1;
 
     // transaction has started
-    emit editingStarted();
+    Q_EMIT editingStarted();
     if (m_document)
-        emit m_document->KTextEditor::Document::editingStarted(m_document);
+        Q_EMIT m_document->KTextEditor::Document::editingStarted(m_document);
 
     // first transaction started
     return true;
@@ -217,9 +217,9 @@ bool TextBuffer::finishEditing()
     Q_ASSERT(!editingChangedBuffer() || (m_editingMaximalLineChanged >= 0 && m_editingMaximalLineChanged < m_lines));
 
     // transaction has finished
-    emit editingFinished();
+    Q_EMIT editingFinished();
     if (m_document)
-        emit m_document->KTextEditor::Document::editingFinished(m_document);
+        Q_EMIT m_document->KTextEditor::Document::editingFinished(m_document);
 
     // last transaction finished
     return true;
@@ -261,9 +261,9 @@ void TextBuffer::wrapLine(const KTextEditor::Cursor &position)
     balanceBlock(blockIndex);
 
     // emit signal about done change
-    emit lineWrapped(position);
+    Q_EMIT lineWrapped(position);
     if (m_document)
-        emit m_document->KTextEditor::Document::lineWrapped(m_document, position);
+        Q_EMIT m_document->KTextEditor::Document::lineWrapped(m_document, position);
 }
 
 void TextBuffer::unwrapLine(int line)
@@ -313,9 +313,9 @@ void TextBuffer::unwrapLine(int line)
     balanceBlock(blockIndex);
 
     // emit signal about done change
-    emit lineUnwrapped(line);
+    Q_EMIT lineUnwrapped(line);
     if (m_document)
-        emit m_document->KTextEditor::Document::lineUnwrapped(m_document, line);
+        Q_EMIT m_document->KTextEditor::Document::lineUnwrapped(m_document, line);
 }
 
 void TextBuffer::insertText(const KTextEditor::Cursor &position, const QString &text)
@@ -350,9 +350,9 @@ void TextBuffer::insertText(const KTextEditor::Cursor &position, const QString &
     }
 
     // emit signal about done change
-    emit textInserted(position, text);
+    Q_EMIT textInserted(position, text);
     if (m_document)
-        emit m_document->KTextEditor::Document::textInserted(m_document, position, text);
+        Q_EMIT m_document->KTextEditor::Document::textInserted(m_document, position, text);
 }
 
 void TextBuffer::removeText(const KTextEditor::Range &range)
@@ -395,9 +395,9 @@ void TextBuffer::removeText(const KTextEditor::Range &range)
     }
 
     // emit signal about done change
-    emit textRemoved(range, text);
+    Q_EMIT textRemoved(range, text);
     if (m_document)
-        emit m_document->KTextEditor::Document::textRemoved(m_document, range, text);
+        Q_EMIT m_document->KTextEditor::Document::textRemoved(m_document, range, text);
 }
 
 int TextBuffer::blockForLine(int line) const
@@ -408,11 +408,11 @@ int TextBuffer::blockForLine(int line) const
     }
 
     // we need blocks and last used block should not be negative
-    Q_ASSERT(!m_blocks.isEmpty());
+    Q_ASSERT(!m_blocks.empty());
     Q_ASSERT(m_lastUsedBlock >= 0);
 
     // shortcut: try last block first
-    if (m_lastUsedBlock < m_blocks.size()) {
+    if (m_lastUsedBlock < (int)m_blocks.size()) {
         // check if block matches
         // if yes, just return again this block
         TextBlock *block = m_blocks[m_lastUsedBlock];
@@ -432,7 +432,7 @@ int TextBuffer::blockForLine(int line) const
         // get middle and ensure it is OK
         int middle = blockStart + ((blockEnd - blockStart) / 2);
         Q_ASSERT(middle >= 0);
-        Q_ASSERT(middle < m_blocks.size());
+        Q_ASSERT(middle < (int)m_blocks.size());
 
         // facts bout this block
         TextBlock *block = m_blocks[middle];
@@ -462,14 +462,14 @@ void TextBuffer::fixStartLines(int startBlock)
 {
     // only allow valid start block
     Q_ASSERT(startBlock >= 0);
-    Q_ASSERT(startBlock < m_blocks.size());
+    Q_ASSERT(startBlock < (int)m_blocks.size());
 
     // new start line for next block
     TextBlock *block = m_blocks.at(startBlock);
     int newStartLine = block->startLine() + block->lines();
 
     // fixup block
-    for (int index = startBlock + 1; index < m_blocks.size(); ++index) {
+    for (size_t index = startBlock + 1; index < m_blocks.size(); ++index) {
         // set new start line
         block = m_blocks.at(index);
         block->setStartLine(newStartLine);
@@ -528,7 +528,7 @@ void TextBuffer::debugPrint(const QString &title) const
     printf("%s (lines: %d bs: %d)\n", qPrintable(title), m_lines, m_blockSize);
 
     // print all blocks
-    for (int i = 0; i < m_blocks.size(); ++i) {
+    for (size_t i = 0; i < m_blocks.size(); ++i) {
         m_blocks.at(i)->debugPrint(i);
     }
 }
@@ -554,7 +554,7 @@ bool TextBuffer::load(const QString &filename, bool &encodingErrors, bool &tooLo
     // 3) use again given encoding, be done in any case
     for (int i = 0; i < (enforceTextCodec ? 1 : 4); ++i) {
         // kill all blocks beside first one
-        for (int b = 1; b < m_blocks.size(); ++b) {
+        for (size_t b = 1; b < m_blocks.size(); ++b) {
             TextBlock *block = m_blocks.at(b);
             block->clearLines();
             delete block;
@@ -562,7 +562,7 @@ bool TextBuffer::load(const QString &filename, bool &encodingErrors, bool &tooLo
         m_blocks.resize(1);
 
         // remove lines in first block
-        m_blocks.last()->clearLines();
+        m_blocks.back()->clearLines();
         m_lines = 0;
 
         // try to open file, with given encoding
@@ -578,7 +578,7 @@ bool TextBuffer::load(const QString &filename, bool &encodingErrors, bool &tooLo
 
         if (!file.open(codec)) {
             // create one dummy textline, in any case
-            m_blocks.last()->appendLine(QString());
+            m_blocks.back()->appendLine(QString());
             m_lines++;
             return false;
         }
@@ -610,7 +610,8 @@ bool TextBuffer::load(const QString &filename, bool &encodingErrors, bool &tooLo
                 if ((m_lineLengthLimit > 0) && (lineLength > m_lineLengthLimit)) {
                     // search for place to wrap
                     int spacePosition = m_lineLengthLimit - 1;
-                    for (int testPosition = m_lineLengthLimit - 1; (testPosition >= 0) && (testPosition >= (m_lineLengthLimit - (m_lineLengthLimit / 10))); --testPosition) {
+                    for (int testPosition = m_lineLengthLimit - 1; (testPosition >= 0) && (testPosition >= (m_lineLengthLimit - (m_lineLengthLimit / 10)));
+                         --testPosition) {
                         // wrap place found?
                         if (unicodeData[testPosition].isSpace() || unicodeData[testPosition].isPunct()) {
                             spacePosition = testPosition;
@@ -633,12 +634,12 @@ bool TextBuffer::load(const QString &filename, bool &encodingErrors, bool &tooLo
                 unicodeData += lineLength;
 
                 // ensure blocks aren't too large
-                if (m_blocks.last()->lines() >= m_blockSize) {
-                    m_blocks.append(new TextBlock(this, m_blocks.last()->startLine() + m_blocks.last()->lines()));
+                if (m_blocks.back()->lines() >= m_blockSize) {
+                    m_blocks.push_back(new TextBlock(this, m_blocks.back()->startLine() + m_blocks.back()->lines()));
                 }
 
                 // append line to last block
-                m_blocks.last()->appendLine(textLine);
+                m_blocks.back()->appendLine(textLine);
                 ++m_lines;
             } while (length > 0);
         }
@@ -680,7 +681,7 @@ bool TextBuffer::load(const QString &filename, bool &encodingErrors, bool &tooLo
     BUFFER_DEBUG << "used filter device for mime-type" << m_mimeTypeForFilterDev;
 
     // emit success
-    emit loaded(filename, encodingErrors);
+    Q_EMIT loaded(filename, encodingErrors);
 
     // file loading worked, modulo encoding problems
     return true;
@@ -734,7 +735,7 @@ bool TextBuffer::save(const QString &filename)
     markModifiedLinesAsSaved();
 
     // emit that file was saved and be done
-    emit saved(filename);
+    Q_EMIT saved(filename);
     return true;
 }
 
@@ -921,7 +922,7 @@ bool TextBuffer::saveBufferEscalated(const QString &filename)
     return true;
 }
 
-void TextBuffer::notifyAboutRangeChange(KTextEditor::View *view, int startLine, int endLine, bool rangeWithAttribute)
+void TextBuffer::notifyAboutRangeChange(KTextEditor::View *view, KTextEditor::LineRange lineRange, bool rangeWithAttribute)
 {
     // ignore calls if no document is around
     if (!m_document) {
@@ -938,7 +939,7 @@ void TextBuffer::notifyAboutRangeChange(KTextEditor::View *view, int startLine,
         }
 
         // notify view, it is really a kate view
-        static_cast<KTextEditor::ViewPrivate *>(curView)->notifyAboutRangeChange(startLine, endLine, rangeWithAttribute);
+        static_cast<KTextEditor::ViewPrivate *>(curView)->notifyAboutRangeChange(lineRange, rangeWithAttribute);
     }
 }
 
@@ -949,40 +950,4 @@ void TextBuffer::markModifiedLinesAsSaved()
     }
 }
 
-QList<TextRange *> TextBuffer::rangesForLine(int line, KTextEditor::View *view, bool rangesWithAttributeOnly) const
-{
-    // get block, this will assert on invalid line
-    const int blockIndex = blockForLine(line);
-
-    // get the ranges of the right block
-    QList<TextRange *> rightRanges;
-    const auto blockRanges = m_blocks.at(blockIndex)->rangesForLine(line);
-    for (const QSet<TextRange *> &ranges : blockRanges) {
-        for (TextRange *const range : ranges) {
-            // we want only ranges with attributes, but this one has none
-            if (rangesWithAttributeOnly && !range->hasAttribute()) {
-                continue;
-            }
-
-            // we want ranges for no view, but this one's attribute is only valid for views
-            if (!view && range->attributeOnlyForViews()) {
-                continue;
-            }
-
-            // the range's attribute is not valid for this view
-            if (range->view() && range->view() != view) {
-                continue;
-            }
-
-            // if line is in the range, ok
-            if (range->startInternal().lineInternal() <= line && line <= range->endInternal().lineInternal()) {
-                rightRanges.append(range);
-            }
-        }
-    }
-
-    // return right ranges
-    return rightRanges;
-}
-
 }
