@@ -1,22 +1,8 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2005-2014 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2005-2014 Dominik Haumann <dhaumann@kde.org>
 
-    Copyright (C) 2005-2014 Christoph Cullmann <cullmann@kde.org>
-    Copyright (C) 2005-2014 Dominik Haumann (dhaumann@kde.org)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KTEXTEDITOR_EDITOR_H
@@ -27,9 +13,17 @@
 #include <QObject>
 #include <QVector>
 
+// theme support
+#include <KSyntaxHighlighting/Theme>
+
 class KAboutData;
 class KConfig;
 
+namespace KSyntaxHighlighting
+{
+class Repository;
+}
+
 /**
  * The KTextEditor namespace contains all the public API that is required
  * to use the KTextEditor component. Using the KTextEditor interfaces is
@@ -226,6 +220,51 @@ public:
      */
     virtual ConfigPage *configPage(int number, QWidget *parent) = 0;
 
+Q_SIGNALS:
+    /**
+     * This signal is emitted whenever the editor configuration is changed.
+     *
+     * \param editor the editor which's config has changed
+     *
+     * \since 5.79
+     */
+    void configChanged(KTextEditor::Editor *editor);
+
+public:
+    /**
+     * Get the current global theme.
+     * Might change during runtime, configChanged() will be emitted in that cases.
+     * Individual views might have set different themes, \see KTextEditor::View::theme().
+     *
+     * \return current global theme for all views
+     *
+     * \since 5.79
+     */
+    KSyntaxHighlighting::Theme theme() const;
+
+public:
+    /**
+     * Get read-only access to the syntax highlighting repository the editor uses.
+     * Might be reloaded during runtime, repositoryReloaded() will be emitted in that cases.
+     *
+     * \return syntax repository used by the editor
+     *
+     * \since 5.79
+     */
+    const KSyntaxHighlighting::Repository &repository() const;
+
+Q_SIGNALS:
+    /**
+     * This signal is emitted whenever the editor syntax repository is reloaded.
+     * Can be used to e.g. re-instantiate syntax definitions that got invalidated by
+     * the repository reload.
+     *
+     * \param editor the editor which's repository was reloaded
+     *
+     * \since 5.79
+     */
+    void repositoryReloaded(KTextEditor::Editor *editor);
+
 public:
     /**
      * Query for the command \p cmd.
