@@ -1,22 +1,8 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2001-2010 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2009 Erlend Hamberg <ehamberg@gmail.com>
 
-    Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
-    Copyright (C) 2009 Erlend Hamberg <ehamberg@gmail.com>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KATE_GLOBAL_H
@@ -45,7 +31,6 @@ class QStringListModel;
 
 class KateCmd;
 class KateModeManager;
-class KateSchemaManager;
 class KateGlobalConfig;
 class KateDocumentConfig;
 class KateViewConfig;
@@ -65,7 +50,6 @@ class KateSpellCheckManager;
 class KateWordCompletionModel;
 class KateAbstractInputModeFactory;
 class KateKeywordCompletionModel;
-class KateDefaultColors;
 class KateVariableExpansionManager;
 
 namespace KTextEditor
@@ -231,7 +215,7 @@ public:
      */
     QList<KTextEditor::ViewPrivate *> views()
     {
-        return m_views.toList();
+        return m_views.values();
     }
 
     /**
@@ -259,15 +243,6 @@ public:
         return m_modeManager;
     }
 
-    /**
-     * manager for the katepart schemas
-     * @return schema manager
-     */
-    KateSchemaManager *schemaManager()
-    {
-        return m_schemaManager;
-    }
-
     /**
      * fallback document config
      * @return default config for all documents
@@ -405,15 +380,6 @@ public:
      */
     QList<KateAbstractInputModeFactory *> inputModeFactories();
 
-    /**
-     * Default colors, once constructed, as expensive
-     * @return default colors
-     */
-    const KateDefaultColors &defaultColors() const
-    {
-        return *m_defaultColors;
-    }
-
     /**
      * Search pattern history shared among simple/power search instances.
      */
@@ -434,6 +400,18 @@ public:
      */
     KateVariableExpansionManager *variableExpansionManager();
 
+    /**
+     * Trigger delayed emission of config changed.
+     */
+    void triggerConfigChanged();
+
+private Q_SLOTS:
+    /**
+     * Emit configChanged if needed.
+     * Used to bundle emissions.
+     */
+    void emitConfigChanged();
+
 Q_SIGNALS:
     /**
      * Emitted if the history of clipboard changes via copyToClipboard
@@ -472,11 +450,6 @@ private:
      */
     KateModeManager *m_modeManager;
 
-    /**
-     * schema manager
-     */
-    KateSchemaManager *m_schemaManager;
-
     /**
      * global config
      */
@@ -562,16 +535,19 @@ private:
      */
     QMap<KTextEditor::View::InputMode, KateAbstractInputModeFactory *> m_inputModeFactories;
 
-    /**
-     * default colors
-     */
-    QScopedPointer<KateDefaultColors> m_defaultColors;
-
     /**
      * Shared history models for search & replace.
      */
     QStringListModel *m_searchHistoryModel;
     QStringListModel *m_replaceHistoryModel;
+
+    /**
+     * We collapse configChanged signals to avoid that e.g.
+     * Document/View/Renderer/... updates cause X emitted signals in a row.
+     * This bool tells if we still shall emit a signal in the delayed connected
+     * slot.
+     */
+    bool m_configWasChanged = false;
 };
 
 }
