@@ -1,20 +1,7 @@
-/* This file is part of the KDE project
-   Copyright (C) 2001 Christoph Cullmann (cullmann@kde.org)
+/*
+    SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kateview.h"
@@ -32,45 +19,48 @@
 #include "plugin.h"
 
 #include "command.h"
-#include "inlinenoteinterface.h"
 #include "inlinenote.h"
 #include "inlinenotedata.h"
+#include "inlinenoteinterface.h"
 #include "inlinenoteprovider.h"
+#include "katevariableexpansionmanager.h"
 #include "markinterface.h"
 #include "modificationinterface.h"
 #include "sessionconfiginterface.h"
 #include "texthintinterface.h"
 #include "variable.h"
 
-#include "annotationinterface.h"
 #include "abstractannotationitemdelegate.h"
+#include "annotationinterface.h"
 
-#include "kateglobal.h"
-#include "kateconfig.h"
 #include "katecmd.h"
-#include "katemacroexpander.h"
+#include "kateconfig.h"
+#include "kateglobal.h"
+#include "katesyntaxmanager.h"
 
 using namespace KTextEditor;
 
-Cursor Cursor::fromString(const QStringRef& str) Q_DECL_NOEXCEPT
+Cursor Cursor::fromString(const QStringRef &str) Q_DECL_NOEXCEPT
+{
+    return fromString(QStringView(str));
+}
+
+Cursor Cursor::fromString(QStringView str) Q_DECL_NOEXCEPT
 {
     // parse format "(line, column)"
     const int startIndex = str.indexOf(QLatin1Char('('));
     const int endIndex = str.indexOf(QLatin1Char(')'));
     const int commaIndex = str.indexOf(QLatin1Char(','));
 
-    if (startIndex < 0 || endIndex < 0 || commaIndex < 0 ||
-        commaIndex < startIndex || endIndex < commaIndex ||
-        endIndex < startIndex)
-    {
+    if (startIndex < 0 || endIndex < 0 || commaIndex < 0 || commaIndex < startIndex || endIndex < commaIndex || endIndex < startIndex) {
         return invalid();
     }
 
     bool ok1 = false;
     bool ok2 = false;
 
-    const int line = str.mid(startIndex + 1, commaIndex - startIndex - 1).toInt(&ok1);
-    const int column = str.mid(commaIndex + 1, endIndex - commaIndex - 1).toInt(&ok2);
+    const int line = str.mid(startIndex + 1, commaIndex - startIndex - 1).toString().toInt(&ok1); // FIXME KF6, Qt 5.15.2 and higher
+    const int column = str.mid(commaIndex + 1, endIndex - commaIndex - 1).toString().toInt(&ok2); // FIXME KF6, Qt 5.15.2 and higher
 
     if (!ok1 || !ok2) {
         return invalid();
@@ -80,8 +70,8 @@ Cursor Cursor::fromString(const QStringRef& str) Q_DECL_NOEXCEPT
 }
 
 Editor::Editor(EditorPrivate *impl)
-    : QObject ()
-    , d (impl)
+    : QObject()
+    , d(impl)
 {
 }
 
@@ -91,92 +81,61 @@ Editor::~Editor()
 
 Editor *KTextEditor::Editor::instance()
 {
-    /**
-     * Just use internal KTextEditor::EditorPrivate::self()
-     */
+    // Just use internal KTextEditor::EditorPrivate::self()
     return KTextEditor::EditorPrivate::self();
 }
 
-QString Editor::defaultEncoding () const
+QString Editor::defaultEncoding() const
 {
-    /**
-     * return default encoding in global config object
-     */
-    return d->documentConfig()->encoding ();
+    // return default encoding in global config object
+    return d->documentConfig()->encoding();
 }
 
-bool Editor::registerVariableMatch(const QString& name, const QString& description, ExpandFunction expansionFunc)
+bool Editor::registerVariableMatch(const QString &name, const QString &description, ExpandFunction expansionFunc)
 {
-    if (name.isEmpty() || expansionFunc == nullptr)
-        return false;
-
-    if (d->m_variableExactMatches.contains(name))
-        return false;
-
-    d->m_variableExactMatches.insert(name, Variable(name, description, expansionFunc));
-    return true;
+    const auto var = Variable(name, description, expansionFunc, false);
+    return d->variableExpansionManager()->addVariable(var);
 }
 
-bool Editor::registerVariablePrefix(const QString& prefix, const QString& description, ExpandFunction expansionFunc)
+bool Editor::registerVariablePrefix(const QString &prefix, const QString &description, ExpandFunction expansionFunc)
 {
-    if (prefix.isEmpty() || expansionFunc == nullptr)
-        return false;
-
-    if (d->m_variablePrefixMatches.contains(prefix))
-        return false;
-
-    if (!prefix.contains(QLatin1Char(':')))
-        return false;
-
-    d->m_variablePrefixMatches.insert(prefix, Variable(prefix, description, expansionFunc));
-    return true;
+    const auto var = Variable(prefix, description, expansionFunc, true);
+    return d->variableExpansionManager()->addVariable(var);
 }
 
-bool Editor::unregisterVariableMatch(const QString& variable)
+bool Editor::unregisterVariableMatch(const QString &variable)
 {
-    auto it = d->m_variableExactMatches.find(variable);
-    if (it != d->m_variableExactMatches.end()) {
-        d->m_variableExactMatches.erase(it);
-        return true;
-    }
-    return false;
+    return d->variableExpansionManager()->removeVariable(variable);
 }
 
-bool Editor::unregisterVariablePrefix(const QString& variable)
+bool Editor::unregisterVariablePrefix(const QString &variable)
 {
-    auto it = d->m_variablePrefixMatches.find(variable);
-    if (it != d->m_variablePrefixMatches.end()) {
-        d->m_variablePrefixMatches.erase(it);
-        return true;
-    }
-    return false;
+    return d->variableExpansionManager()->removeVariable(variable);
 }
 
-bool Editor::expandVariable(const QString& variable, KTextEditor::View* view, QString& output) const
+bool Editor::expandVariable(const QString &variable, KTextEditor::View *view, QString &output) const
 {
-    // first try exact matches
-    const auto it = d->m_variableExactMatches.find(variable);
-    if (it != d->m_variableExactMatches.end()) {
-        output = it->evaluate(variable, view);
-        return true;
-    }
-
-    // try prefix matching
-    const int colonIndex = variable.indexOf(QLatin1Char(':'));
-    if (colonIndex >= 0) {
-        const QString prefix = variable.left(colonIndex + 1);
-        const auto itPrefix = d->m_variablePrefixMatches.find(prefix);
-        if (itPrefix != d->m_variablePrefixMatches.end()) {
-            output = itPrefix->evaluate(variable, view);
-            return true;
-        }
-    }
-    return false;
+    return d->variableExpansionManager()->expandVariable(variable, view, output);
 }
 
-void Editor::expandText(const QString& text, KTextEditor::View* view, QString& output) const
+void Editor::expandText(const QString &text, KTextEditor::View *view, QString &output) const
 {
-    output = KateMacroExpander::expandMacro(text, view);
+    output = d->variableExpansionManager()->expandText(text, view);
+}
+
+void Editor::addVariableExpansion(const QVector<QWidget *> &widgets, const QStringList &variables) const
+{
+    d->variableExpansionManager()->showDialog(widgets, variables);
+}
+
+KSyntaxHighlighting::Theme Editor::theme() const
+{
+    return KateHlManager::self()->repository().theme(d->rendererConfig()->schema());
+}
+
+const KSyntaxHighlighting::Repository &Editor::repository() const
+{
+    return KateHlManager::self()->repository();
 }
 
 bool View::insertText(const QString &text)
@@ -190,29 +149,21 @@ bool View::insertText(const QString &text)
 
 bool View::isStatusBarEnabled() const
 {
-    /**
-     * is the status bar around?
-     */
+    // is the status bar around?
     return !!d->statusBar();
 }
 
 void View::setStatusBarEnabled(bool enable)
 {
-    /**
-     * no state change, do nothing
-     */
+    // no state change, do nothing
     if (enable == !!d->statusBar())
         return;
 
-    /**
-     * else toggle it
-     */
-    d->toggleStatusBar ();
+    // else toggle it
+    d->toggleStatusBar();
 }
 
-bool View::insertTemplate(const KTextEditor::Cursor& insertPosition,
-                          const QString& templateString,
-                          const QString& script)
+bool View::insertTemplate(const KTextEditor::Cursor &insertPosition, const QString &templateString, const QString &script)
 {
     return d->insertTemplateInternal(insertPosition, templateString, script);
 }
@@ -222,13 +173,20 @@ void View::setViewInputMode(InputMode inputMode)
     d->setInputMode(inputMode);
 }
 
+KSyntaxHighlighting::Theme View::theme() const
+{
+    return KateHlManager::self()->repository().theme(d->renderer()->config()->schema());
+}
+
 ConfigPage::ConfigPage(QWidget *parent)
     : QWidget(parent)
     , d(nullptr)
-{}
+{
+}
 
 ConfigPage::~ConfigPage()
-{}
+{
+}
 
 QString ConfigPage::fullName() const
 {
@@ -240,21 +198,26 @@ QIcon ConfigPage::icon() const
     return QIcon::fromTheme(QStringLiteral("document-properties"));
 }
 
-View::View (ViewPrivate *impl, QWidget *parent)
-    : QWidget (parent), KXMLGUIClient()
+View::View(ViewPrivate *impl, QWidget *parent)
+    : QWidget(parent)
+    , KXMLGUIClient()
     , d(impl)
-{}
+{
+}
 
 View::~View()
-{}
+{
+}
 
 Plugin::Plugin(QObject *parent)
     : QObject(parent)
     , d(nullptr)
-{}
+{
+}
 
 Plugin::~Plugin()
-{}
+{
+}
 
 int Plugin::configPages() const
 {
@@ -267,53 +230,67 @@ ConfigPage *Plugin::configPage(int, QWidget *)
 }
 
 MarkInterface::MarkInterface()
-{}
+{
+}
 
 MarkInterface::~MarkInterface()
-{}
+{
+}
 
 ModificationInterface::ModificationInterface()
-{}
+{
+}
 
 ModificationInterface::~ModificationInterface()
-{}
+{
+}
 
 SessionConfigInterface::SessionConfigInterface()
-{}
+{
+}
 
 SessionConfigInterface::~SessionConfigInterface()
-{}
+{
+}
 
 TextHintInterface::TextHintInterface()
-{}
+{
+}
 
 TextHintInterface::~TextHintInterface()
-{}
+{
+}
 
 TextHintProvider::TextHintProvider()
-{}
+{
+}
 
 TextHintProvider::~TextHintProvider()
-{}
+{
+}
 
 InlineNoteInterface::InlineNoteInterface()
-{}
+{
+}
 
 InlineNoteInterface::~InlineNoteInterface()
-{}
+{
+}
 
 InlineNoteProvider::InlineNoteProvider()
-{}
+{
+}
 
 InlineNoteProvider::~InlineNoteProvider()
-{}
+{
+}
 
-KateInlineNoteData::KateInlineNoteData(KTextEditor::InlineNoteProvider* provider,
-                                       const KTextEditor::View* view,
-                                       const KTextEditor::Cursor& position,
+KateInlineNoteData::KateInlineNoteData(KTextEditor::InlineNoteProvider *provider,
+                                       const KTextEditor::View *view,
+                                       const KTextEditor::Cursor &position,
                                        int index,
                                        bool underMouse,
-                                       const QFont& font,
+                                       const QFont &font,
                                        int lineHeight)
     : m_provider(provider)
     , m_view(view)
@@ -322,9 +299,10 @@ KateInlineNoteData::KateInlineNoteData(KTextEditor::InlineNoteProvider* provider
     , m_underMouse(underMouse)
     , m_font(font)
     , m_lineHeight(lineHeight)
-{}
+{
+}
 
-InlineNote::InlineNote(const KateInlineNoteData& data)
+InlineNote::InlineNote(const KateInlineNoteData &data)
     : d(data)
 {
 }
@@ -339,36 +317,36 @@ bool KTextEditor::InlineNote::underMouse() const
     return d.m_underMouse;
 }
 
-void KTextEditor::InlineNoteProvider::inlineNoteActivated(const InlineNote& note, Qt::MouseButtons buttons, const QPoint& globalPos)
+void KTextEditor::InlineNoteProvider::inlineNoteActivated(const InlineNote &note, Qt::MouseButtons buttons, const QPoint &globalPos)
 {
     Q_UNUSED(note);
     Q_UNUSED(buttons);
     Q_UNUSED(globalPos);
 }
 
-void KTextEditor::InlineNoteProvider::inlineNoteFocusInEvent(const KTextEditor::InlineNote& note, const QPoint& globalPos)
+void KTextEditor::InlineNoteProvider::inlineNoteFocusInEvent(const KTextEditor::InlineNote &note, const QPoint &globalPos)
 {
     Q_UNUSED(note);
     Q_UNUSED(globalPos);
 }
 
-void KTextEditor::InlineNoteProvider::inlineNoteFocusOutEvent(const KTextEditor::InlineNote& note)
+void KTextEditor::InlineNoteProvider::inlineNoteFocusOutEvent(const KTextEditor::InlineNote &note)
 {
     Q_UNUSED(note);
 }
 
-void KTextEditor::InlineNoteProvider::inlineNoteMouseMoveEvent(const KTextEditor::InlineNote& note, const QPoint& globalPos)
+void KTextEditor::InlineNoteProvider::inlineNoteMouseMoveEvent(const KTextEditor::InlineNote &note, const QPoint &globalPos)
 {
     Q_UNUSED(note);
     Q_UNUSED(globalPos);
 }
 
-KTextEditor::InlineNoteProvider* InlineNote::provider() const
+KTextEditor::InlineNoteProvider *InlineNote::provider() const
 {
     return d.m_provider;
 }
 
-const KTextEditor::View* InlineNote::view() const
+const KTextEditor::View *InlineNote::view() const
 {
     return d.m_view;
 }
@@ -395,18 +373,18 @@ KTextEditor::Cursor InlineNote::position() const
 
 Command::Command(const QStringList &cmds, QObject *parent)
     : QObject(parent)
-    , m_cmds (cmds)
+    , m_cmds(cmds)
     , d(nullptr)
 {
     // register this command
-    static_cast<KTextEditor::EditorPrivate *> (KTextEditor::Editor::instance())->cmdManager()->registerCommand (this);
+    static_cast<KTextEditor::EditorPrivate *>(KTextEditor::Editor::instance())->cmdManager()->registerCommand(this);
 }
 
 Command::~Command()
 {
     // unregister this command, if instance is still there!
     if (KTextEditor::Editor::instance())
-        static_cast<KTextEditor::EditorPrivate *> (KTextEditor::Editor::instance())->cmdManager()->unregisterCommand (this);
+        static_cast<KTextEditor::EditorPrivate *>(KTextEditor::Editor::instance())->cmdManager()->unregisterCommand(this);
 }
 
 bool Command::supportsRange(const QString &)
@@ -460,7 +438,8 @@ QRect View::textAreaRect() const
 
 StyleOptionAnnotationItem::StyleOptionAnnotationItem()
     : contentFontMetrics(QFont())
-{}
+{
+}
 
 StyleOptionAnnotationItem::StyleOptionAnnotationItem(const StyleOptionAnnotationItem &other)
     : QStyleOption(Version, Type)
@@ -472,10 +451,12 @@ StyleOptionAnnotationItem::StyleOptionAnnotationItem(const StyleOptionAnnotation
 StyleOptionAnnotationItem::StyleOptionAnnotationItem(int version)
     : QStyleOption(version, Type)
     , contentFontMetrics(QFont())
-{}
+{
+}
 
 AbstractAnnotationItemDelegate::AbstractAnnotationItemDelegate(QObject *parent)
     : QObject(parent)
-{}
+{
+}
 
 AbstractAnnotationItemDelegate::~AbstractAnnotationItemDelegate() = default;
